 /*---------------------------------------------------------------------------
                  Copyright (c) 2005 demmel products
         This example demo code is provided as is and has no warranty,
     implied or otherwise.  You are free to use/modify any of the provided
    code at your own risk in your applications with the expressed limitation
    of liability (see below) so long as your product using the code contains
                      at least one uPSD products (device).

    LIMITATION OF LIABILITY:   NEITHER demmel products NOR ITS VENDORS OR
   AGENTS SHALL BE LIABLE FOR ANY LOSS OF PROFITS, LOSS OF USE, LOSS OF DATA,
       INTERRUPTION OF BUSINESS, NOR FOR INDIRECT, SPECIAL, INCIDENTAL OR
       CONSEQUENTIAL DAMAGES OF ANY KIND WHETHER UNDER THIS AGREEMENT OR
         OTHERWISE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
  --------------------------------------------------------------------------*/

#ifndef I_i2c
#define I_i2c

#include "typedefs.h"

// Bit definements for status byte got from the iLCD controller
#define SB_DATA_AVAIL		0x01		// If set, some data bytes are available for reading
#define SB_IN_OVR				0x20		// Indicates receive data overrun, that means the iLCD
												// controller could not process all data (never happens if the
												// command response is evaluated) - automatically reset after
												// status has been read
#define SB_OUT_OVR			0x40		// Indicates transmit data overrun, that means the iLCD
												// controller could not send all data because they were not retrieved
												// in time - automatically reset after status has been read

// Initialize I2C and assign I2C address
void i2c_init(byte i2c_addr);

// Returns status from the iLCD controller.
// Call i2c_get_result() after calling this function to check if there was an error.
byte i2c_read_status();

// Read # of bytes contrained in output queue of the iLCD controller.
// Call i2c_get_result() after calling this function to check if there was an error.
byte i2c_read_data_size();

// Read info from the iLCD controller. The returned word contains the status
// in the high byte and the # of bytes in the output buffer in low byte.
// Call i2c_get_result() after calling this function to check if there was an error.
word i2c_read_info();

// Write a block of data ('count' bytes) to the iLCD controller.
// Returns true if successful.
bool i2c_write_block(byte *out_data, byte count);

// Read a block of data (max. 'count' bytes) from the iLCD controller.
// Returns # of bytes read. If any error occurs, -1 is returned. If the
// read buffer disposed by the caller ('count' length) is too small,
// count + 0x100 is returned and only 'count' bytes are read.
// The rest fo the available data can be read at any time by another call
// to i2c_read_block().
int i2c_read_block(byte *in_data, byte count);

#define i2c_get_result()	i2c_result
extern bool i2c_result;
#endif
